summaryrefslogtreecommitdiff
path: root/source3/utils/net_registry.c
diff options
context:
space:
mode:
Diffstat (limited to 'source3/utils/net_registry.c')
-rw-r--r--source3/utils/net_registry.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/source3/utils/net_registry.c b/source3/utils/net_registry.c
index a504bcfd0b6..d6cdd982c3d 100644
--- a/source3/utils/net_registry.c
+++ b/source3/utils/net_registry.c
@@ -412,10 +412,10 @@ static int net_registry_getsd(struct net_context *c, int argc,
TALLOC_CTX *ctx = talloc_stackframe();
uint32_t access_mask = REG_KEY_READ |
SEC_FLAG_MAXIMUM_ALLOWED |
- SEC_RIGHT_SYSTEM_SECURITY;
+ SEC_FLAG_SYSTEM_SECURITY;
/*
* net_rpc_regsitry uses SEC_RIGHT_SYSTEM_SECURITY, but access
* is denied with these perms right now...
*/
access_mask = REG_KEY_READ;
@@ -412,10 +412,10 @@ static int net_registry_getsd(struct net_context *c, int argc,
/*
- * net_rpc_regsitry uses SEC_RIGHT_SYSTEM_SECURITY, but access
+ * net_rpc_regsitry uses SEC_FLAG_SYSTEM_SECURITY, but access
* is denied with these perms right now...
*/